..
   This is an autogenerated file from processors.rst

avatars.processors.InterRecordCumulatedDifferenceProcessor
==========================================================

.. autoclass:: avatars.processors.InterRecordCumulatedDifferenceProcessor
   :members: